@@ -22,14 +22,12 @@ ENV = os.environ['ENV'] # Must be set
 SERVICE_NAME = os.environ['SERVICE_NAME']
 LOCAL_DEPLOYMENT = os.getenv('LOCAL_DEPLOYMENT') # Optional
 
-deployment_platform = 'gc' # 'cdf'
-
 
 def deploy(model_settings):
 
     for setting in model_settings:
         (model_name, model_file, model_req_file, model_artifact_folder,
-        info, model_test_file) = setting
+        info, model_test_file, deployment_platform) = setting
         
         logging.info(f"Deploy model {model_name}")
 
